PyXMake Developer Guide: PyXMake.Build.Make.Coverage Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
PyXMake.Build.Make.Coverage Class Reference

Base class for all Coverage build events. More...

Inheritance diagram for PyXMake.Build.Make.Coverage:

## Public Member Functions
| __init__ (self, *args, **kwargs)
| __call__ (self, fn)
| show (cls)
| add (cls, *args, **kwargs)
| parse (cls, **kwargs)
| Build (self, command=["--cov-fail-under=10","--cov-report=term-missing","--cov-report=html","--cov-report=xml","--junit-xml=junit.xml", "-W ignore::pytest.PytestAssertRewriteWarning"], **kwargs)
| create (self, **kwargs)
Public Member Functions inherited from PyXMake.Build.Make.Make
| __posix__ (self, **kwargs)
| AddIncludePath (self, includes)
| AddDependencyPath (self, dependencies)
| UseLibraries (self, libs)
| SourcePath (self, path)
| OutputPath (self, path, files="")
| Environment (self, path, script="ifortvars.bat")
| Preprocessing (self, cmdstring='', inend='', outend='', copyfiles=[], replace={'!DEC$ IF':'#IF','!DEC$ ELSE':'#ELSE','!DEC$ ENDIF':'#ENDIF'})
| Postprocessing (self, cmdstring='')
| run (cls, **kwargs)
Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __new__ (cls, *args, **kwargs)
| recover (cls, *args)
| classify (cls, *args, **kwargs)
| jsonify (self)
| update (self, **kwargs)
| __repr__ (self)
| __str__ (self)
| __getstate__ (self)
| __setstate__ (self, _dict)

## Public Attributes
bool | isDecorator = kwargs.pop("__as_decorator",any(line.startswith('@') for line in inspect.stack(context=2)[1].code_context))
str | MakeObjectKind = 'Coverage'
| String identifier of current instance.
list | incdirs = []
| args = args
| kwargs = kwargs
| makecmd = command
| verbose = kwargs.get("verbosity",1)
| srcdir
| srcs
| outdir
Public Attributes inherited from PyXMake.Build.Make.Make
| buildid = BuildID
| Base string of build object.
list | srcs = []
| Source file or folders.
list | bare = not BuildID and not self.srcs
| stype = kwargs.get("stype",'Fortran')
| Source file type.
| verbose = verbose
| Level of verbosity of the current build object.
| hasFoss = kwargs.get("foss", Utility.GetExecutable("choco") or Utility.GetPlatform() in ["linux"] or kwargs.get("bash",False))
| Toggle between free open source software and commercial 3rd party libraries.
| scrtdir = os.getcwd()
| Current scratch directory
| srcdir = os.getcwd()
| Default search directory for source files.
| outdir = os.getcwd()
| Default search directory for output.
_, self.intelpath, self.iniCompiler | intelpath = content
| Path to Intel Fortran Compiler (read from Paths.log or empty).
tuple | temps = ()
| Tuple of data to be removed after job completion.
list | incdirs = []
| List of include directories.
list | libdirs = []
| List of library directories.
list | libs = []
| List of actual libraries (by name) used during linking.
list | copyfiles = []
| List of files to be copied to the output directory after finish.
str | iniCompiler = ""
| Default initialization of compiler script.
bool | setarch = True if kwargs.get('arch', None) in ['x86', 'x64'] else False
| Define the architecture for the build directly by using the keyword argument "arch".
| msvsc = kwargs.get("msvsc",'vs2015')
| Default version of Microsoft visual studio used by the Intel Fortran Compiler.
str | architecture = 'x86'
| Processor architecture.
str | postcmd = ""
| Post build command.
| buildname = self.temps + (inputfile, )
str | precmd = self.iniCompiler+" "+cmdstring
| Command executed during pre-build event.
| compargs = cmdstring
| Command line arguments passed in by the user.
str | makecmd = self.iniCompiler+" "+os.path.join(self.path2exe,self.exe)+" "+ cmd + cmdstring
| Command executed during build event.
| mkl_dependency

## Additional Inherited Members
Static Public Member Functions inherited from PyXMake.Build.Make.Make
| __parser__ ()
| Detach ()
| F2CPreprocessing (PreprocessingFile)
| sanitize (string, **kwargs)
| setup (*args, **kwargs)
Static Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __getbase__ (base, cls)
Protected Attributes inherited from PyXMake.Build.Make.Make
list | _mkl_includes = [x for x in self.incdirs if "mkl" in x]

## Detailed Description

Base class for all Coverage build events.

    Inherited class to automatically build a coverage report using Coverage.

Inherited from Make.

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.Build.Make.Coverage.__init__ | ( |  | self,
|  | * | args,
|  | ** | kwargs )

    Initialization of coverage class object.

Reimplemented from PyXMake.Build.Make.Make.

Definition at line 3481 of file Make.py.

## Member Function Documentation

## ◆ __call__()

PyXMake.Build.Make.Coverage.__call__ | ( |  | self,
|  |  | fn )

    Implement an executable variant if class is used as a decorator.

Definition at line 3501 of file Make.py.

## ◆ add()

PyXMake.Build.Make.Coverage.add | ( |  | cls,
|  | * | args,
|  | ** | kwargs )

    Provide a test case for the given method as a decorator.

Definition at line 3546 of file Make.py.

## ◆ Build()

PyXMake.Build.Make.Coverage.Build | ( |  | self,
|  |  | command = ["--cov-fail-under=10","--cov-report=term-missing","--cov-report=html","--cov-report=xml","--junit-xml=junit.xml", "-W ignore::pytest.PytestAssertRewriteWarning"],
|  | ** | kwargs )

    Assemble command strings for the main build event.

Reimplemented from PyXMake.Build.Make.Make.

Definition at line 3620 of file Make.py.

## ◆ create()

PyXMake.Build.Make.Coverage.create | ( |  | self,
|  | ** | kwargs )

    Execute make command

Reimplemented from PyXMake.Build.Make.Make.

Definition at line 3630 of file Make.py.

## ◆ parse()

PyXMake.Build.Make.Coverage.parse | ( |  | cls,
|  | ** | kwargs )

    Execute the current class as a CLI command.

Definition at line 3559 of file Make.py.

## ◆ show()

PyXMake.Build.Make.Coverage.show | ( |  | cls | ) |

    Get a boolean value if this function is called within an active test environment

Definition at line 3538 of file Make.py.

## Member Data Documentation

## ◆ args

PyXMake.Build.Make.Coverage.args = args

Definition at line 3498 of file Make.py.

## ◆ incdirs

list PyXMake.Build.Make.Coverage.incdirs = []

Definition at line 3495 of file Make.py.

## ◆ isDecorator

bool PyXMake.Build.Make.Coverage.isDecorator = kwargs.pop("__as_decorator",any(line.startswith('@') for line in inspect.stack(context=2)[1].code_context))

Definition at line 3486 of file Make.py.

## ◆ kwargs

PyXMake.Build.Make.Coverage.kwargs = kwargs

Definition at line 3499 of file Make.py.

## ◆ makecmd

PyXMake.Build.Make.Coverage.makecmd = command

Definition at line 3626 of file Make.py.

## ◆ MakeObjectKind

str PyXMake.Build.Make.Coverage.MakeObjectKind = 'Coverage'

String identifier of current instance.

Definition at line 3493 of file Make.py.

## ◆ outdir

PyXMake.Build.Make.Coverage.outdir

Definition at line 3753 of file Make.py.

## ◆ srcdir

PyXMake.Build.Make.Coverage.srcdir

Definition at line 3691 of file Make.py.

## ◆ srcs

PyXMake.Build.Make.Coverage.srcs

Definition at line 3694 of file Make.py.

## ◆ verbose

PyXMake.Build.Make.Coverage.verbose = kwargs.get("verbosity",1)

Definition at line 3657 of file Make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Build/Make.py